@@ -25,7 +25,11 @@
 #ifndef TESTING_GEBSR2GEBSR_HPP
 #define TESTING_GEBSR2GEBSR_HPP
 
+#include "display.hpp"
+#include "flops.hpp"
+#include "gbyte.hpp"
 #include "hipsparse.hpp"
+#include "hipsparse_arguments.hpp"
 #include "hipsparse_test_unique_ptr.hpp"
 #include "unit.hpp"
 #include "utility.hpp"
@@ -37,10 +41,10 @@ template <typename T>
 void testing_gebsr2gebsr_bad_arg(void)
 {
 #if(!defined(CUDART_VERSION))
-    int                  mb              = 100;
-    int                  nb              = 100;
-    int                  nnzb            = 100;
-    int                  safe_size       = 100;
+    int                  mb              = 1;
+    int                  nb              = 1;
+    int                  nnzb            = 1;
+    int                  safe_size       = 1;
     int                  row_block_dim_A = 2;
     int                  col_block_dim_A = 2;
     int                  row_block_dim_C = 2;
@@ -61,21 +65,21 @@ void testing_gebsr2gebsr_bad_arg(void)
     hipsparseSetMatIndexBase(descr_C, idx_base_C);
 
     auto bsr_row_ptr_A_managed
-        = hipsparse_unique_ptr{device_malloc(sizeof(int) * safe_size), device_free};
+        = hipsparse_unique_ptr{device_malloc(sizeof(int) * (safe_size + 1)), device_free};
     auto bsr_col_ind_A_managed
         = hipsparse_unique_ptr{device_malloc(sizeof(int) * safe_size), device_free};
     auto bsr_val_A_managed
         = hipsparse_unique_ptr{device_malloc(sizeof(T) * safe_size), device_free};
     auto bsr_row_ptr_C_managed
-        = hipsparse_unique_ptr{device_malloc(sizeof(int) * safe_size), device_free};
+        = hipsparse_unique_ptr{device_malloc(sizeof(int) * (safe_size + 1)), device_free};
     auto bsr_col_ind_C_managed
         = hipsparse_unique_ptr{device_malloc(sizeof(int) * safe_size), device_free};
     auto bsr_val_C_managed
         = hipsparse_unique_ptr{device_malloc(sizeof(T) * safe_size), device_free};
     auto temp_buffer_managed
         = hipsparse_unique_ptr{device_malloc(sizeof(T) * safe_size), device_free};
-
     int* bsr_row_ptr_A = (int*)bsr_row_ptr_A_managed.get();
+
     int* bsr_col_ind_A = (int*)bsr_col_ind_A_managed.get();
     T*   bsr_val_A     = (T*)bsr_val_A_managed.get();
     int* bsr_row_ptr_C = (int*)bsr_row_ptr_C_managed.get();
@@ -83,12 +87,11 @@ void testing_gebsr2gebsr_bad_arg(void)
     T*   bsr_val_C     = (T*)bsr_val_C_managed.get();
     T*   temp_buffer   = (T*)temp_buffer_managed.get();
 
-    if(!bsr_row_ptr_A || !bsr_col_ind_A || !bsr_val_A || !bsr_row_ptr_C || !bsr_col_ind_C
-       || !bsr_val_C || !temp_buffer)
-    {
-        PRINT_IF_HIP_ERROR(hipErrorOutOfMemory);
-        return;
-    }
+    int local_ptr[2] = {0, 1};
+    CHECK_HIP_ERROR(
+        hipMemcpy(bsr_row_ptr_A, local_ptr, sizeof(int) * (safe_size + 1), hipMemcpyHostToDevice));
+    CHECK_HIP_ERROR(
+        hipMemcpy(bsr_row_ptr_C, local_ptr, sizeof(int) * (safe_size + 1), hipMemcpyHostToDevice));
 
     // Testing hipsparseXgebsr2gebsr_bufferSize()
 
@@ -437,24 +440,6 @@ void testing_gebsr2gebsr_bad_arg(void)
                                       temp_buffer);
     verify_hipsparse_status_invalid_pointer(status, "Error: nnz_total_dev_host_ptr is nullptr");
 
-    status = hipsparseXgebsr2gebsrNnz(handle,
-                                      dir,
-                                      mb,
-                                      nb,
-                                      nnzb,
-                                      descr_A,
-                                      bsr_row_ptr_A,
-                                      bsr_col_ind_A,
-                                      row_block_dim_A,
-                                      col_block_dim_A,
-                                      descr_C,
-                                      bsr_row_ptr_C,
-                                      row_block_dim_C,
-                                      col_block_dim_C,
-                                      &nnz_total_dev_host_ptr,
-                                      nullptr);
-    verify_hipsparse_status_invalid_pointer(status, "Error: buffer is nullptr");
-
     // Test invalid sizes
     status = hipsparseXgebsr2gebsrNnz(handle,
                                       dir,
@@ -724,6 +709,7 @@ void testing_gebsr2gebsr_bad_arg(void)
                                    row_block_dim_C,
                                    col_block_dim_C,
                                    temp_buffer);
+
     verify_hipsparse_status_invalid_pointer(status, "Error: bsr_val_C is nullptr");
 
     status = hipsparseXgebsr2gebsr(handle,
@@ -766,26 +752,6 @@ void testing_gebsr2gebsr_bad_arg(void)
                                    temp_buffer);
     verify_hipsparse_status_invalid_pointer(status, "Error: bsr_col_ind_C is nullptr");
 
-    status = hipsparseXgebsr2gebsr(handle,
-                                   dir,
-                                   mb,
-                                   nb,
-                                   nnzb,
-                                   descr_A,
-                                   bsr_val_A,
-                                   bsr_row_ptr_A,
-                                   bsr_col_ind_A,
-                                   row_block_dim_A,
-                                   col_block_dim_A,
-                                   descr_C,
-                                   bsr_val_C,
-                                   bsr_row_ptr_C,
-                                   bsr_col_ind_C,
-                                   row_block_dim_C,
-                                   col_block_dim_C,
-                                   nullptr);
-    verify_hipsparse_status_invalid_pointer(status, "Error: temp_buffer is nullptr");
-
     // Test invalid sizes
     status = hipsparseXgebsr2gebsr(handle,
                                    dir,
@@ -938,34 +904,10 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
     int                  col_block_dim_A = argus.col_block_dimA;
     int                  row_block_dim_C = argus.row_block_dimB;
     int                  col_block_dim_C = argus.col_block_dimB;
-    hipsparseIndexBase_t idx_base_A      = argus.idx_base;
-    hipsparseIndexBase_t idx_base_C      = argus.idx_base2;
+    hipsparseIndexBase_t idx_base_A      = argus.baseA;
+    hipsparseIndexBase_t idx_base_C      = argus.baseB;
     hipsparseDirection_t dir             = argus.dirA;
-    std::string          binfile         = "";
-    std::string          filename        = "";
-    hipsparseStatus_t    status;
-
-    // When in testing mode, M == N == -99 indicates that we are testing with a real
-    // matrix from cise.ufl.edu
-    int safe_size = 100;
-    if(m == -99 && n == -99 && argus.timing == 0)
-    {
-        binfile = argus.filename;
-        m = n = safe_size;
-    }
-
-    if(argus.timing == 1)
-    {
-        filename = argus.filename;
-    }
-
-    int mb = -1;
-    int nb = -1;
-    if(row_block_dim_A > 0 && col_block_dim_A > 0)
-    {
-        mb = (m + row_block_dim_A - 1) / row_block_dim_A;
-        nb = (n + col_block_dim_A - 1) / col_block_dim_A;
-    }
+    std::string          filename        = argus.filename;
 
     std::unique_ptr<handle_struct> unique_ptr_handle(new handle_struct);
     hipsparseHandle_t              handle = unique_ptr_handle->handle;
@@ -977,125 +919,34 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
     hipsparseSetMatIndexBase(descr_A, idx_base_A);
     hipsparseSetMatIndexBase(descr_C, idx_base_C);
 
-    // Argument sanity check before allocating invalid memory
-    if(mb <= 0 || nb <= 0 || row_block_dim_A <= 0 || col_block_dim_A <= 0 || row_block_dim_C <= 0
-       || col_block_dim_C <= 0)
+    if(m == 0 || n == 0)
     {
-        auto dtemp_buffer_managed
-            = hipsparse_unique_ptr{device_malloc(sizeof(T) * safe_size), device_free};
-
-        T* dtemp_buffer = (T*)dtemp_buffer_managed.get();
-
-        if(!dtemp_buffer)
-        {
-            verify_hipsparse_status_success(HIPSPARSE_STATUS_ALLOC_FAILED, "!dtemp_buffer");
-            return HIPSPARSE_STATUS_ALLOC_FAILED;
-        }
-
-        status = hipsparseXgebsr2gebsr(handle,
-                                       dir,
-                                       mb,
-                                       nb,
-                                       safe_size,
-                                       descr_A,
-                                       (const T*)nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       row_block_dim_A,
-                                       col_block_dim_A,
-                                       descr_C,
-                                       (T*)nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       row_block_dim_C,
-                                       col_block_dim_C,
-                                       dtemp_buffer);
-
-        if(mb < 0 || nb < 0 || row_block_dim_A <= 0 || col_block_dim_A <= 0 || row_block_dim_C <= 0
-           || col_block_dim_C <= 0)
-        {
-            verify_hipsparse_status_invalid_size(
-                status,
-                "Error: mb < 0 || nb < 0 || row_block_dim_A <= 0 || col_block_dim_A <= 0 || "
-                "row_block_dim_C <= 0 || col_block_dim_C <= 0");
-        }
-        else
-        {
-            verify_hipsparse_status_success(
-                status,
-                "mb >= 0 && nb >= 0 && row_block_dim_A > 0 && col_block_dim_A > 0 && "
-                "row_block_dim_C > 0 && col_block_dim_C > 0");
-        }
-
+#ifdef __HIP_PLATFORM_NVIDIA__
+        // cusparse does not support m == 0 for csr2bsr
         return HIPSPARSE_STATUS_SUCCESS;
+#endif
     }
 
+    srand(12345ULL);
+
     // Host structures
     std::vector<int> hcsr_row_ptr;
     std::vector<int> hcsr_col_ind;
     std::vector<T>   hcsr_val;
-    int              nnz;
 
-    // Initial Data on CPU
-    srand(12345ULL);
-    if(binfile != "")
+    // Read or construct CSR matrix
+    int nnz = 0;
+    if(!generate_csr_matrix(filename, m, n, nnz, hcsr_row_ptr, hcsr_col_ind, hcsr_val, idx_base_A))
     {
-        if(read_bin_matrix(
-               binfile.c_str(), m, n, nnz, hcsr_row_ptr, hcsr_col_ind, hcsr_val, idx_base_A)
-           != 0)
-        {
-            fprintf(stderr, "Cannot open [read] %s\n", binfile.c_str());
-            return HIPSPARSE_STATUS_INTERNAL_ERROR;
-        }
-    }
-    else if(argus.laplacian)
-    {
-        m = n = gen_2d_laplacian(argus.laplacian, hcsr_row_ptr, hcsr_col_ind, hcsr_val, idx_base_A);
-        nnz   = hcsr_row_ptr[m];
-    }
-    else
-    {
-        std::vector<int> coo_row_ind;
-
-        if(filename != "")
-        {
-            if(read_mtx_matrix(
-                   filename.c_str(), m, n, nnz, coo_row_ind, hcsr_col_ind, hcsr_val, idx_base_A)
-               != 0)
-            {
-                fprintf(stderr, "Cannot open [read] %s\n", filename.c_str());
-                return HIPSPARSE_STATUS_INTERNAL_ERROR;
-            }
-        }
-        else
-        {
-            double scale = 0.02;
-            if(m > 1000 || n > 1000)
-            {
-                scale = 2.0 / std::max(m, n);
-            }
-            nnz = m * scale * n;
-            gen_matrix_coo(m, n, nnz, coo_row_ind, hcsr_col_ind, hcsr_val, idx_base_A);
-        }
-
-        // Convert COO to CSR
-        hcsr_row_ptr.resize(m + 1, 0);
-        for(int i = 0; i < nnz; ++i)
-        {
-            ++hcsr_row_ptr[coo_row_ind[i] + 1 - idx_base_A];
-        }
-
-        hcsr_row_ptr[0] = idx_base_A;
-        for(int i = 0; i < m; ++i)
-        {
-            hcsr_row_ptr[i + 1] += hcsr_row_ptr[i];
-        }
+        fprintf(stderr, "Cannot open [read] %s\ncol", filename.c_str());
+        return HIPSPARSE_STATUS_INTERNAL_ERROR;
     }
 
     // mb and nb can be modified if reading from a file
-    mb       = (m + row_block_dim_A - 1) / row_block_dim_A;
-    nb       = (n + col_block_dim_A - 1) / col_block_dim_A;
+    int mb   = (m + row_block_dim_A - 1) / row_block_dim_A;
+    int nb   = (n + col_block_dim_A - 1) / col_block_dim_A;
     int mb_C = (mb * row_block_dim_A + row_block_dim_C - 1) / row_block_dim_C;
+    int nb_C = (nb * col_block_dim_A + col_block_dim_C - 1) / col_block_dim_C;
 
     // allocate memory on device
     auto dcsr_row_ptr_managed
@@ -1110,13 +961,6 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
     T*   dcsr_val       = (T*)dcsr_val_managed.get();
     int* dbsr_row_ptr_A = (int*)dbsr_row_ptr_A_managed.get();
 
-    if(!dcsr_val || !dcsr_row_ptr || !dcsr_col_ind || !dbsr_row_ptr_A)
-    {
-        verify_hipsparse_status_success(HIPSPARSE_STATUS_ALLOC_FAILED,
-                                        "!dval || !dptr || !dcol || !dbsr_row_ptr_A");
-        return HIPSPARSE_STATUS_ALLOC_FAILED;
-    }
-
     // copy data from CPU to device
     CHECK_HIP_ERROR(
         hipMemcpy(dcsr_row_ptr, hcsr_row_ptr.data(), sizeof(int) * (m + 1), hipMemcpyHostToDevice));
@@ -1141,12 +985,6 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
         = hipsparse_unique_ptr{device_malloc(buffer_size_conversion), device_free};
     void* dbuffer_conversion = dbuffer_conversion_managed.get();
 
-    if(!dbuffer_conversion)
-    {
-        verify_hipsparse_status_success(HIPSPARSE_STATUS_ALLOC_FAILED, "!dbuffer_conversion");
-        return HIPSPARSE_STATUS_ALLOC_FAILED;
-    }
-
     // Obtain BSR nnzb first on the host and then using the device and ensure they give the same results
     CHECK_HIPSPARSE_ERROR(hipsparseSetPointerMode(handle, HIPSPARSE_POINTER_MODE_HOST));
 
@@ -1177,13 +1015,6 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
     T*   dbsr_val_A     = (T*)dbsr_val_A_managed.get();
     int* dbsr_row_ptr_C = (int*)dbsr_row_ptr_C_managed.get();
 
-    if(!dbsr_col_ind_A || !dbsr_val_A || !dbsr_row_ptr_C)
-    {
-        verify_hipsparse_status_success(HIPSPARSE_STATUS_ALLOC_FAILED,
-                                        "!dbsr_col_ind_A || !dbsr_val_A || !dbsr_row_ptr_C");
-        return HIPSPARSE_STATUS_ALLOC_FAILED;
-    }
-
     CHECK_HIPSPARSE_ERROR(hipsparseXcsr2gebsr(handle,
                                               dir,
                                               m,
@@ -1236,79 +1067,69 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
 
     void* dbuffer = (void*)dbuffer_managed.get();
 
-    if(!dbuffer)
-    {
-        verify_hipsparse_status_success(HIPSPARSE_STATUS_ALLOC_FAILED, "!dbuffer");
-        return HIPSPARSE_STATUS_ALLOC_FAILED;
-    }
+    // Obtain BSR nnzb first on the host and then using the device and ensure they give the same results
+    CHECK_HIPSPARSE_ERROR(hipsparseSetPointerMode(handle, HIPSPARSE_POINTER_MODE_HOST));
+
+    int hnnzb_C;
+    CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsrNnz(handle,
+                                                   dir,
+                                                   mb,
+                                                   nb,
+                                                   nnzb,
+                                                   descr_A,
+                                                   dbsr_row_ptr_A,
+                                                   dbsr_col_ind_A,
+                                                   row_block_dim_A,
+                                                   col_block_dim_A,
+                                                   descr_C,
+                                                   dbsr_row_ptr_C,
+                                                   row_block_dim_C,
+                                                   col_block_dim_C,
+                                                   &hnnzb_C,
+                                                   dbuffer));
+
+    CHECK_HIPSPARSE_ERROR(hipsparseSetPointerMode(handle, HIPSPARSE_POINTER_MODE_DEVICE));
+
+    auto dnnzb_C_managed = hipsparse_unique_ptr{device_malloc(sizeof(int)), device_free};
+    int* dnnzb_C         = (int*)dnnzb_C_managed.get();
+    CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsrNnz(handle,
+                                                   dir,
+                                                   mb,
+                                                   nb,
+                                                   nnzb,
+                                                   descr_A,
+                                                   dbsr_row_ptr_A,
+                                                   dbsr_col_ind_A,
+                                                   row_block_dim_A,
+                                                   col_block_dim_A,
+                                                   descr_C,
+                                                   dbsr_row_ptr_C,
+                                                   row_block_dim_C,
+                                                   col_block_dim_C,
+                                                   dnnzb_C,
+                                                   dbuffer));
+
+    int hnnzb_C_copied_from_device;
+    CHECK_HIP_ERROR(
+        hipMemcpy(&hnnzb_C_copied_from_device, dnnzb_C, sizeof(int), hipMemcpyDeviceToHost));
 
     if(argus.unit_check)
     {
-        // Obtain BSR nnzb first on the host and then using the device and ensure they give the same results
-        CHECK_HIPSPARSE_ERROR(hipsparseSetPointerMode(handle, HIPSPARSE_POINTER_MODE_HOST));
-
-        int hnnzb_C;
-        CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsrNnz(handle,
-                                                       dir,
-                                                       mb,
-                                                       nb,
-                                                       nnzb,
-                                                       descr_A,
-                                                       dbsr_row_ptr_A,
-                                                       dbsr_col_ind_A,
-                                                       row_block_dim_A,
-                                                       col_block_dim_A,
-                                                       descr_C,
-                                                       dbsr_row_ptr_C,
-                                                       row_block_dim_C,
-                                                       col_block_dim_C,
-                                                       &hnnzb_C,
-                                                       dbuffer));
-
-        CHECK_HIPSPARSE_ERROR(hipsparseSetPointerMode(handle, HIPSPARSE_POINTER_MODE_DEVICE));
-
-        auto dnnzb_C_managed = hipsparse_unique_ptr{device_malloc(sizeof(int)), device_free};
-        int* dnnzb_C         = (int*)dnnzb_C_managed.get();
-        CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsrNnz(handle,
-                                                       dir,
-                                                       mb,
-                                                       nb,
-                                                       nnzb,
-                                                       descr_A,
-                                                       dbsr_row_ptr_A,
-                                                       dbsr_col_ind_A,
-                                                       row_block_dim_A,
-                                                       col_block_dim_A,
-                                                       descr_C,
-                                                       dbsr_row_ptr_C,
-                                                       row_block_dim_C,
-                                                       col_block_dim_C,
-                                                       dnnzb_C,
-                                                       dbuffer));
-
-        int hnnzb_C_copied_from_device;
-        CHECK_HIP_ERROR(
-            hipMemcpy(&hnnzb_C_copied_from_device, dnnzb_C, sizeof(int), hipMemcpyDeviceToHost));
-
         // Check that using host and device pointer mode gives the same result
         unit_check_general(1, 1, 1, &hnnzb_C_copied_from_device, &hnnzb_C);
+    }
 
-        // Allocate memory on the device
-        auto dbsr_col_ind_C_managed
-            = hipsparse_unique_ptr{device_malloc(sizeof(int) * hnnzb_C), device_free};
-        auto dbsr_val_C_managed = hipsparse_unique_ptr{
-            device_malloc(sizeof(T) * hnnzb_C * row_block_dim_C * col_block_dim_C), device_free};
+    // Allocate memory on the device
+    auto dbsr_col_ind_C_managed
+        = hipsparse_unique_ptr{device_malloc(sizeof(int) * hnnzb_C), device_free};
+    auto dbsr_val_C_managed = hipsparse_unique_ptr{
+        device_malloc(sizeof(T) * hnnzb_C * row_block_dim_C * col_block_dim_C), device_free};
 
-        int* dbsr_col_ind_C = (int*)dbsr_col_ind_C_managed.get();
-        T*   dbsr_val_C     = (T*)dbsr_val_C_managed.get();
-
-        if(!dbsr_col_ind_C || !dbsr_val_C)
-        {
-            verify_hipsparse_status_success(HIPSPARSE_STATUS_ALLOC_FAILED,
-                                            "!bsr_col_ind_C || !bsr_val_C");
-            return HIPSPARSE_STATUS_ALLOC_FAILED;
-        }
+    int* dbsr_col_ind_C = (int*)dbsr_col_ind_C_managed.get();
+    T*   dbsr_val_C     = (T*)dbsr_val_C_managed.get();
 
+    if(argus.unit_check)
+    {
         CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsr(handle,
                                                     dir,
                                                     mb,
@@ -1380,6 +1201,103 @@ hipsparseStatus_t testing_gebsr2gebsr(Arguments argus)
                            hbsr_val_C.data());
     }
 
+    if(argus.timing)
+    {
+        int number_cold_calls = 2;
+        int number_hot_calls  = argus.iters;
+
+        CHECK_HIPSPARSE_ERROR(hipsparseSetPointerMode(handle, HIPSPARSE_POINTER_MODE_HOST));
+
+        // Warm up
+        for(int iter = 0; iter < number_cold_calls; ++iter)
+        {
+            CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsr(handle,
+                                                        dir,
+                                                        mb,
+                                                        nb,
+                                                        nnzb,
+                                                        descr_A,
+                                                        dbsr_val_A,
+                                                        dbsr_row_ptr_A,
+                                                        dbsr_col_ind_A,
+                                                        row_block_dim_A,
+                                                        col_block_dim_A,
+                                                        descr_C,
+                                                        dbsr_val_C,
+                                                        dbsr_row_ptr_C,
+                                                        dbsr_col_ind_C,
+                                                        row_block_dim_C,
+                                                        col_block_dim_C,
+                                                        dbuffer));
+        }
+
+        double gpu_time_used = get_time_us();
+
+        // Performance run
+        for(int iter = 0; iter < number_hot_calls; ++iter)
+        {
+            CHECK_HIPSPARSE_ERROR(hipsparseXgebsr2gebsr(handle,
+                                                        dir,
+                                                        mb,
+                                                        nb,
+                                                        nnzb,
+                                                        descr_A,
+                                                        dbsr_val_A,
+                                                        dbsr_row_ptr_A,
+                                                        dbsr_col_ind_A,
+                                                        row_block_dim_A,
+                                                        col_block_dim_A,
+                                                        descr_C,
+                                                        dbsr_val_C,
+                                                        dbsr_row_ptr_C,
+                                                        dbsr_col_ind_C,
+                                                        row_block_dim_C,
+                                                        col_block_dim_C,
+                                                        dbuffer));
+        }
+
+        gpu_time_used = (get_time_us() - gpu_time_used) / number_hot_calls;
+
+        double gbyte_count = gebsr2gebsr_gbyte_count<T>(mb,
+                                                        mb_C,
+                                                        row_block_dim_A,
+                                                        col_block_dim_A,
+                                                        row_block_dim_C,
+                                                        col_block_dim_C,
+                                                        nnzb,
+                                                        hnnzb_C);
+        double gpu_gbyte   = get_gpu_gbyte(gpu_time_used, gbyte_count);
+
+        display_timing_info(display_key_t::M,
+                            m,
+                            display_key_t::N,
+                            n,
+                            display_key_t::MbA,
+                            mb,
+                            display_key_t::NbA,
+                            nb,
+                            display_key_t::MbC,
+                            mb_C,
+                            display_key_t::NbC,
+                            nb_C,
+                            display_key_t::row_block_dimA,
+                            row_block_dim_A,
+                            display_key_t::col_block_dimA,
+                            col_block_dim_A,
+                            display_key_t::row_block_dimC,
+                            row_block_dim_C,
+                            display_key_t::col_block_dimC,
+                            col_block_dim_C,
+                            display_key_t::nnzbA,
+                            nnzb,
+                            display_key_t::nnzbC,
+                            hnnzb_C,
+                            display_key_t::bandwidth,
+                            gpu_gbyte,
+                            display_key_t::time_ms,
+                            get_gpu_time_msec(gpu_time_used));
+    }
+
     return HIPSPARSE_STATUS_SUCCESS;
 }
 
