@@ -262,7 +262,7 @@ int main(int argc, char** argv)
     int ret = RUN_ALL_TESTS();
 
     // Reset HIP device
-    hipDeviceReset();
+    (void)hipDeviceReset();
 
     return ret;
 }
